const loginDebug = require('debug')('graphed:login')
const logoutDebug = require('debug')('graphed:logout')
const config = require('./config')
const path = require('path')
const uuid = require('uuid-v4')
const request = require('request')
const normapi = require('normapi')

let api = new normapi()

const login = object => {
  return new Promise((resolve, reject) => {
    const url = path.join(config.loginUrl, object.appId)
    request.post({
      headers: {
        'content-type': 'application/x-www-form-urlencoded'
      },
      url: url,
      form: {
          uniquekey: uuid()
        , email: object.email
        , password: object.password
        , fingerprint: object.fingerprint
        , lalo: object.lalo
        , keepmeloggedin: object.keepmeloggedin
      }
    }
    , (err, res, body) => {
      loginDebug(err, body)
      if(err) reject({
        type: 'request-error',
        func: '@login',
        lCode: '-E1',
        msg: 'Hiba a szerver csatlakozás közben!'
      })
      else {
        try {
          body = JSON.parse(body)
          if(body.error) reject({
            type: 'authentication-error',
            func: '@login',
            lCode: '-E2',
            msg: 'Sikertelen bejelentkezés!'
          })
          else resolve({
            func: '@login',
            lCode: '-S1',
            msg: 'Sikeres bejelentkezés!',
            document: body
          })
        }
        catch(e) {reject(e)}
      }
    })
  })
}

const logout = object => {
  return new Promise((resolve, reject) => {
    const url = path.join(config.logoutUrl, object.appId)
    request.post({
      headers: {
        'content-type': 'application/x-www-form-urlencoded'
      },
      url: url,
      form: {
        uniquekey: object.loggedUser,
        fingerprint: object.fingerprint,
        lalo: object.location
      }
    }
    , (err, res, body) => {
      logoutDebug(err, body)
      if(err) reject({
        type: 'request-error',
        func: '@logout',
        lCode: '-E1',
        msg: 'Hiba a szerver csatlakozás közben!'
      })
      else {
        try {
          body = JSON.parse(body)
          if(body.error) reject({
            type:'authentication-error',
            func: '@logout',
            lCode: '-E2',
            msg: 'Sikertelen kilépés!'
          })
          else resolve({
            func: '@graphedLogin-LOGOUT',
            lCode: '-S1',
            msg: 'Sikeres kilépés!',
            document: body
          })
        } 
        catch(e) {reject(e)}
      }
    })
  })
}

api.addFunction({name: 'login'}, login)
api.addFunction({name: 'logout'}, logout)

module.exposts = api